@@ -16,6 +16,7 @@ pub use container::ContainerExt;
 pub use daemon_set::DaemonSetExt;
 pub use deployment::DeploymentExt;
 pub use env::EnvVarExt;
+pub use job::JobExt;
 pub use label_selector::LabelSelectorExt;
 pub use namespace::NamespaceExt;
 pub use pod_spec::PodSpecExt;
@@ -40,6 +41,7 @@ mod container;
 mod daemon_set;
 mod deployment;
 mod env;
+mod job;
 mod label_selector;
 mod namespace;
 mod pod_spec;
